==> dnet-hadoop-service-1.0.3-20141104.095226-5-sources.jar: eu/dnetlib/data/hadoop/action/SubmitOozieJobAction.java <==
package eu.dnetlib.data.hadoop.action;

import java.io.IOException;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.hadoop.conf.Configuration;
import org.apache.oozie.client.OozieClient;

import eu.dnetlib.data.hadoop.HadoopJob;
import eu.dnetlib.data.hadoop.config.ClusterName;
import eu.dnetlib.data.hadoop.oozie.OozieJobMonitor;
import eu.dnetlib.data.hadoop.rmi.HadoopServiceException;
import eu.dnetlib.data.hadoop.utils.JobProfile;
import eu.dnetlib.enabling.tools.blackboard.BlackboardJob;
import eu.dnetlib.enabling.tools.blackboard.BlackboardServerHandler;

public class SubmitOozieJobAction extends AbstractSubmitAction {

	private static final Log log = LogFactory.getLog(SubmitOozieJobAction.class); // NOPMD by marko on 11/24/08 5:02 PM

	@Override
	public void executeAsync(final BlackboardServerHandler handler, final BlackboardJob bbJob) {

		final String jobName = bbJob.getParameters().get("job.name");
		final ClusterName clusterName = ClusterName.valueOf(bbJob.getParameters().get("cluster"));

		try {
			JobProfile jobProfile = loadISJobConfiguration(jobName, bbJob.getParameters());

			validateJobParams(handler, bbJob, jobName, jobProfile);

			Properties jobConf = prepareJob(getConf(clusterName), jobName, jobProfile, bbJob.getParameters());
			log.debug("oozie job configuration:\n" + jobConf);

			if (!clientMap.isOozieAvailable(clusterName)) throw new HadoopServiceException("oozie not available for cluster: " + clusterName.toString());

			logJobDetails(jobConf);

			final OozieClient oozieClient = clientMap.getOozieClient(clusterName);
			final String internalId = oozieClient.run(jobConf);
			final String jobId = newJobId(clusterName, internalId);

			jobRegistry.registerJob(HadoopJob.newInstance(jobId, clusterName, jobProfile,
					new OozieJobMonitor(oozieClient, internalId, newCompletionCallback(handler, bbJob, jobId))));

			updateJobStatus(jobName);
			handler.ongoing(bbJob);
		} catch (Throwable e) {
			log.error("error executing hadoop job: " + jobName, e);
			handler.failed(bbJob, e);
		}
	}

	private Properties prepareJob(final Configuration configuration, final String jobName, final JobProfile jobProfile, final Map<String, String> parameters)
			throws IOException, HadoopServiceException {

		log.info("creating job: " + jobName);

		Properties p = new Properties();

		merge(p, configuration);
		merge(p, jobProfile.getJobDefinition().entrySet());
		merge(p, parameters.entrySet());

		return p;
	}

	private void merge(final Properties p, final Iterable<Entry<String, String>> entrySet) {
		for (Entry<String, String> e : entrySet) {
			p.setProperty(e.getKey(), e.getValue());
		}
	}

	protected void logJobDetails(final Properties jobConf) {
		for (Entry<? extends Object, ? extends Object> e : jobConf.entrySet()) {
			if (log.isDebugEnabled()) {
				log.debug("\n" + e.getKey().toString() + " : " + e.getValue().toString());
			}
		}
	}

}

==> dnet-hadoop-service-1.0.7-20141111.152702-10-sources.jar: eu/dnetlib/data/hadoop/action/SubmitOozieJobAction.java <==
package eu.dnetlib.data.hadoop.action;

import java.util.Map;
import java.util.Map.Entry;
import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.hadoop.conf.Configuration;
import org.apache.oozie.client.OozieClient;

import eu.dnetlib.data.hadoop.HadoopJob;
import eu.dnetlib.data.hadoop.config.ClusterName;
import eu.dnetlib.data.hadoop.oozie.OozieJobMonitor;
import eu.dnetlib.data.hadoop.rmi.HadoopServiceException;
import eu.dnetlib.data.hadoop.utils.JobProfile;
import eu.dnetlib.enabling.tools.blackboard.BlackboardJob;
import eu.dnetlib.enabling.tools.blackboard.BlackboardServerHandler;

public class SubmitOozieJobAction extends AbstractSubmitAction {

	private static final Log log = LogFactory.getLog(SubmitOozieJobAction.class); // NOPMD by marko on 11/24/08 5:02 PM

	@Override
	public void executeAsync(final BlackboardServerHandler handler, final BlackboardJob bbJob) {

		final String jobName = bbJob.getParameters().get("job.name");
		final ClusterName clusterName = ClusterName.valueOf(bbJob.getParameters().get("cluster"));

		try {
			JobProfile jobProfile = loadISJobConfiguration(jobName, bbJob.getParameters());

			validateJobParams(handler, bbJob, jobName, jobProfile);

			Properties jobConf = prepareJob(getConf(clusterName), jobName, jobProfile, bbJob.getParameters());
			log.debug("oozie job configuration:\n" + jobConf);

			if (!hadoopClientMap.isOozieAvailable(clusterName)) throw new HadoopServiceException("oozie not available for cluster: " + clusterName.toString());

			logJobDetails(jobConf);

			final OozieClient oozieClient = hadoopClientMap.getOozieClient(clusterName);
			final String internalId = oozieClient.run(jobConf);
			final String jobId = newJobId(clusterName, internalId);

			jobRegistry.registerJob(HadoopJob.newInstance(jobId, clusterName, jobProfile,
					new OozieJobMonitor(oozieClient, internalId, newCompletionCallback(handler, bbJob, jobId))));

			updateJobStatus(jobName);
			handler.ongoing(bbJob);
		} catch (Throwable e) {
			log.error("error executing hadoop job: " + jobName, e);
			handler.failed(bbJob, e);
		}
	}

	private Properties prepareJob(final Configuration configuration, final String jobName, final JobProfile jobProfile, final Map<String, String> parameters) {

		log.info("creating job: " + jobName);

		Properties p = new Properties();

		merge(p, configuration);
		merge(p, jobProfile.getJobDefinition().entrySet());
		merge(p, parameters.entrySet());

		return p;
	}

	private void merge(final Properties p, final Iterable<Entry<String, String>> entrySet) {
		for (Entry<String, String> e : entrySet) {
			p.setProperty(e.getKey(), e.getValue());
		}
	}

	protected void logJobDetails(final Properties jobConf) {
		for (Entry<?, ?> e : jobConf.entrySet()) {
			if (log.isDebugEnabled()) {
				log.debug("\n" + e.getKey().toString() + " : " + e.getValue().toString());
			}
		}
	}

}
